infra/pkgs/prison-break-url.patch

16 lines
830 B
Diff

diff --git a/prisonbreak/plugins/wifionice.py b/prisonbreak/plugins/wifionice.py
index 1cee64d..e152903 100644
--- a/prisonbreak/plugins/wifionice.py
+++ b/prisonbreak/plugins/wifionice.py
@@ -58,8 +58,8 @@ def accept(resp: requests.Response, s: requests.Session) -> bool:
log.debug(f"data: {postdata}")
# TODO: detect the correct URL to query based on form path and url
- # The URL changed from http to http, and wifionice.de is now wifi.bahn.de
- resp = s.post("https://wifi.bahn.de/de/?url=http%3A%2F%2Fkrebsco.de%2Fsecret", data=postdata)
+ # The URL changed from wifi.bahn.de to login.wifionice.de
+ resp = s.post("https://login.wifionice.de/de/?url=http%3A%2F%2Fkrebsco.de%2Fsecret", data=postdata)
log.debug(f"Return code: {resp.status_code}")
log.debug(resp.headers)
return resp.ok